@@ -1,5 +1,5 @@
 package CatalystX::Fastly::Role::Response;
-$CatalystX::Fastly::Role::Response::VERSION = '0.02';
+$CatalystX::Fastly::Role::Response::VERSION = '0.03';
 use Moose::Role;
 use Carp;
 
@@ -54,7 +54,7 @@ CatalystX::Fastly::Role::Response - Methods for Fastly intergration to Catalyst
 
         $c->add_surrogate_key('FOO','WIBBLE');
 
-        $c->response->body( 'Add cache and surrogate key headers, and purge' );
+        $c->response->body( 'Add cache and surrogate key headers' );
     }
 
 =head1 DESCRIPTION
@@ -273,7 +273,7 @@ automatically by Catalyst.
 
 =cut
 
-sub finalize_headers {
+before 'finalize_headers' => sub {
     my $c = shift;
 
     if ( $c->browser_never_cache ) {
@@ -345,7 +345,7 @@ sub finalize_headers {
         $c->res->header( 'Surrogate-Key' => $c->join_surrogate_keys(' ') );
     }
 
-}
+};
 
 
 =head1 SEE ALSO
